"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.trackQuizConversion = exports.trackQuizResultClick = exports.trackQuizResultsLoaded = exports.getQuizResults = exports.nextQuestion = exports.getCioClient = void 0;
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/naming-convention */
const constructorio_client_javascript_1 = tslib_1.__importDefault(require("@constructor-io/constructorio-client-javascript"));
const getCioClient = (apiKey) => {
    if (apiKey) {
        return new constructorio_client_javascript_1.default({
            apiKey,
            sendTrackingEvents: true,
        });
    }
    return undefined;
};
exports.getCioClient = getCioClient;
const nextQuestion = (cioClient, quizId, parameters) => cioClient === null || cioClient === void 0 ? void 0 : cioClient.quizzes.getQuizNextQuestion(quizId, parameters);
exports.nextQuestion = nextQuestion;
const getQuizResults = (cioClient, quizId, parameters) => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return cioClient === null || cioClient === void 0 ? void 0 : cioClient.quizzes.getQuizResults(quizId, parameters); });
exports.getQuizResults = getQuizResults;
// Tracking requests
const trackQuizResultsLoaded = (cioClient, quizResults) => {
    const { quiz_id, quiz_session_id, quiz_version_id, result_id, request, response } = quizResults;
    cioClient === null || cioClient === void 0 ? void 0 : cioClient.tracker.trackQuizResultsLoaded({
        quiz_id,
        quiz_version_id,
        quiz_session_id,
        url: window.location.href,
        section: request === null || request === void 0 ? void 0 : request.section,
        result_count: response === null || response === void 0 ? void 0 : response.total_num_results,
        result_page: request === null || request === void 0 ? void 0 : request.page,
        result_id,
    });
};
exports.trackQuizResultsLoaded = trackQuizResultsLoaded;
const trackQuizResultClick = (cioClient, quizResults, result, position) => {
    var _a;
    if (quizResults.request && quizResults.response) {
        const { quiz_id, quiz_session_id, quiz_version_id, result_id, request: { section, page, num_results_per_page }, response: { total_num_results }, } = quizResults;
        cioClient === null || cioClient === void 0 ? void 0 : cioClient.tracker.trackQuizResultClick({
            quiz_id,
            quiz_version_id,
            quiz_session_id,
            item_id: (_a = result.data) === null || _a === void 0 ? void 0 : _a.id,
            item_name: result === null || result === void 0 ? void 0 : result.value,
            section,
            result_count: total_num_results,
            result_page: page,
            result_id,
            result_position_on_page: position,
            num_results_per_page,
        });
    }
};
exports.trackQuizResultClick = trackQuizResultClick;
const trackQuizConversion = (cioClient, quizResults, result, price) => {
    var _a, _b;
    if (quizResults.request) {
        const { quiz_id, quiz_session_id, quiz_version_id, request: { section }, } = quizResults;
        cioClient === null || cioClient === void 0 ? void 0 : cioClient.tracker.trackQuizConversion({
            quiz_id,
            quiz_version_id,
            quiz_session_id,
            item_id: (_a = result.data) === null || _a === void 0 ? void 0 : _a.id,
            item_name: result.value,
            section,
            variation_id: (_b = result.data) === null || _b === void 0 ? void 0 : _b.variation_id,
            revenue: (price && String(price)) || undefined,
        });
    }
};
exports.trackQuizConversion = trackQuizConversion;
