import React, { useEffect, useState } from 'react';
import QuizContext from './context';
import QuizQuestions from '../QuizQuestions';
import ResultContainer from '../ResultContainer/ResultContainer';
import { RequestStates } from '../../constants';
import Spinner from '../Spinner/Spinner';
import useQuiz from '../../hooks/useQuiz';
import SessionPromptModal from '../SessionPromptModal/SessionPromptModal';
export default function CioQuiz(props) {
    const { cioClient, state, events: { nextQuestion, previousQuestion, resetQuiz, addToCart, resultClick, hydrateQuiz, hasStoredState, resetStoredState, }, } = useQuiz(props);
    const [showSessionPrompt, setShowSessionPrompt] = useState(false);
    const { resultsPageOptions, sessionStateOptions } = props;
    useEffect(() => {
        // Respect showSessionModal if defined, else default to true.
        if (sessionStateOptions?.showSessionModal !== undefined) {
            setShowSessionPrompt(sessionStateOptions?.showSessionModal && hasStoredState());
        }
        else {
            setShowSessionPrompt(hasStoredState());
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const contextValue = {
        cioClient,
        state,
        nextQuestion,
        previousQuestion,
        resetQuiz,
        addToCart,
        resultClick,
        customClickItemCallback: !!resultsPageOptions?.onQuizResultClick,
    };
    if (state.quiz.requestState === RequestStates.Loading) {
        return (React.createElement("div", { className: 'cio-quiz' },
            React.createElement(Spinner, null)));
    }
    if (state.quiz.requestState === RequestStates.Success) {
        return (React.createElement("div", { className: 'cio-quiz' },
            React.createElement(SessionPromptModal, { resetStoredState: resetStoredState, continueSession: hydrateQuiz, showSessionPrompt: showSessionPrompt, setShowSessionPrompt: setShowSessionPrompt }),
            React.createElement(QuizContext.Provider, { value: contextValue },
                state.quiz.results && React.createElement(ResultContainer, { options: resultsPageOptions }),
                state.quiz.currentQuestion && React.createElement(QuizQuestions, null))));
    }
    return null;
}
